import java.util.Scanner;

// O objetivo do desafio eh verificar se em um determinado tabuleiro, duas rainhas se ameacam

public class Rainhas {
	
	public static void main(String[] args) {
		
		Scanner sc = new Scanner(System.in);
		
		// Recebe o numero de casos de teste e executa o algoritmo
		for (int n = sc.nextInt(); n > 0; n--) {
			
			// Recebe o tamanho e cria o tabuleiro
			int tamanho = sc.nextInt();
			boolean[][] tabuleiro = new boolean[tamanho][tamanho];
			
			// Utiliza duas estruturas booleanas para fazer a verificacao de invalidez
			// A verificacao assim pode ser feito durante o proprio preenchimento do tabuleiro
			boolean[] linhaUsada = new boolean[tamanho];
			boolean[] colunaUsada = new boolean[tamanho];
			
			boolean invalido = false;
			
			// Preenche o tabuleiro conforme a entrada
			for (int l = 0; l < tamanho; l++) {
				for (int c = 0; c < tamanho; c++) {
					
					// Recebe o valor daquela posicao
					int valor = sc.nextInt();
					
					// Se o tabuleiro ja foi declarado invalido
					// Nao eh necessario prosseguir com os calculos
					// Porem, precisamos ler todas as casas
					if (invalido)
						continue;
					
					// Atualiza-se o valor da casa do tabuleiro
					// Verdadeiro se for 1, falso caso contrario
					tabuleiro[l][c] = (valor == 1);
					
					// Se houver uma rainha naquela casa
					if (valor == 1) {
						
						// Verifico se a linha e a coluna ja estao sendo usadas por outra rainha
						if (linhaUsada[l] || colunaUsada[c])
							// Caso sim, o tabuleiro ja eh um tabuleiro invalido
							invalido = true;
						
						// Atualizo as estruturas de verificacao
						linhaUsada[l] = true;
						colunaUsada[c] = true;
					}
				}
			}
			
			// Aqui ocorre a verificao das diagonais, indo para a esquerda e para cima
			// Se o tabuleiro ja foi declarado invalido, nao eh necessario faze-la
			if (!invalido) {
				
				// O metodo diagonalVerifyLeftOk percorre a diagonal indo para cima e para a esquerda
				// Ele inicia em uma casa do tabuleiro
				// Por isso passamos todas as casas das bordas inferior e direita
				
				// Executamos as verificacoes para a metade inferior do tabuleiro
				// Passamos como argumento todas as casas da borda inferior do tabuleiro
				for (int c = 0; c < tamanho; c++) {
					if (!diagonalVerifyLeftOk(tamanho-1, c, tamanho, tabuleiro)) {
						// Caso aquela diagonal aponte mais que uma rainha
						// O tabuleiro eh declarado invalido
						invalido = true;
						// Nao ha necessidade de continuar
						break;
					}
				}
				// Apenas realizamos as verificacoes se o tabuleiro ainda for valido
				if (!invalido)
					// Executamos as verificacoes para a metade superior do tabuleiro
					// Passamos como argumento todas as casas da borda direita do tabuleiro
					for (int l = 0; l < tamanho; l++) {
						if (!diagonalVerifyLeftOk(l, tamanho-1, tamanho, tabuleiro)) {
							// Caso aquela diagonal aponte mais que uma rainha
							// O tabuleiro eh declarado invalido
							invalido = true;
							// Nao ha necessidade de continuar
							break;
						}
					}
			}
			
			// Aqui ocorre a verificao das diagonais, indo para a direita e para cima
			// Se o tabuleiro ja foi declarado invalido, nao eh necessario faze-la
			if (!invalido) {
				
				// O metodo diagonalVerifyRightOk percorre a diagonal indo para cima e para a direita
				// Ele inicia em uma casa do tabuleiro
				// Por isso passamos todas as casas das bordas inferior e esquerda
				
				// Executamos as verificacoes para a metade inferior do tabuleiro
				// Passamos como argumento todas as casas da borda inferior do tabuleiro
				for (int c = 0; c < tamanho; c++) {
					if (!diagonalVerifyRightOk(tamanho-1, c, tamanho, tabuleiro)) {
						// Caso aquela diagonal aponte mais que uma rainha
						// O tabuleiro eh declarado invalido
						invalido = true;
						// Nao ha necessidade de continuar
						break;
					}
				}
				// Apenas realizamos as verificacoes se o tabuleiro ainda for valido
				if (!invalido)
					// Executamos as verificacoes para a metade superior do tabuleiro
					// Passamos como argumento todas as casas da borda esquerda do tabuleiro
					for (int l = 0; l < tamanho; l++) {
						if (!diagonalVerifyRightOk(l, 0, tamanho, tabuleiro)) {
							// Caso aquela diagonal aponte mais que uma rainha
							// O tabuleiro eh declarado invalido
							invalido = true;
							// Nao ha necessidade de continuar
							break;
						}
					}
			}
			
			// Apresentamos o resultado
			if (invalido)
				System.out.println("Invalido");
			else
				System.out.println("Ok");
			
		}		
		sc.close();		
	}
	
	// Esse metodo faz a verificacao das diagonais indo para a esquerda superior
	// A partir de uma casa inicial no tabuleiro
	public static boolean diagonalVerifyLeftOk(int l, int c, int tamanho, boolean[][] tabuleiro) {
		
		// Inicia o contador em 0
		int cont = 0;
		
		// O loop for vai verificando as casas na diagonal esquerda superior da casa inicial
		// Inclusive a propria casa inicial
		// Isso ate atingir as bordas
		for (int i = 0; l-i >= 0 && c-i >= 0; i++) {
			// Se houver uma rainha naquela casa
			if (tabuleiro[l-i][c-i])
				// Incrementamos o contador
				cont++;

			// Se houver mais de uma rainha naquela diagonal
			if (cont > 1)
				// Ja sabemos que a diagonal eh invalida
				// Retornamos 'false' e nao precisamos mais seguir com o algoritmo
				return false;
		}
		
		// Depois de verificar todas as casas, concluimos de que esta eh uma diagonal valida
		return true;
	}
	
	// Esse metodo faz a verificacao das diagonais indo para a direita superior
		// A partir de uma casa inicial no tabuleiro
		public static boolean diagonalVerifyRightOk(int l, int c, int tamanho, boolean[][] tabuleiro) {
			
			// Inicia o contador em 0
			int cont = 0;
			
			// O loop for vai verificando as casas na diagonal direita superior da casa inicial
			// Inclusive a propria casa inicial
			// Isso ate atingir as bordas
			for (int i = 0; l-i >= 0 && c+i < tamanho; i++) {
				// Se houver uma rainha naquela casa
				if (tabuleiro[l-i][c+i])
					// Incrementamos o contador
					cont++;

				// Se houver mais de uma rainha naquela diagonal
				if (cont > 1)
					// Ja sabemos que a diagonal eh invalida
					// Retornamos 'false' e nao precisamos mais seguir com o algoritmo
					return false;
			}
			
			// Depois de verificar todas as casas, concluimos de que esta eh uma diagonal valida
			return true;
		}
}

